@@ -11,6 +11,8 @@ from django.contrib.auth.models import User
 from django.core.exceptions import ImproperlyConfigured
 from django.db.models import get_model
 
+from mezzanine.utils.importing import import_dotted_path
+
 
 def get_profile_model():
     """
@@ -30,6 +32,19 @@ def get_profile_model():
                                    "not be loaded: %s" % profile_model)
 
 
+def get_profile_form():
+    """
+    Returns the profile form defined by ``ACCOUNTS_PROFILE_FORM_CLASS``.
+    """
+    from mezzanine.conf import settings
+    try:
+        return import_dotted_path(settings.ACCOUNTS_PROFILE_FORM_CLASS)
+    except ImportError:
+        raise ImproperlyConfigured("Value for ACCOUNTS_PROFILE_FORM_CLASS "
+                                   "could not be imported: %s" %
+                                   settings.ACCOUNTS_PROFILE_FORM_CLASS)
+
+
 def get_profile_user_fieldname():
     """
     Returns the name of the first field on the profile model that
