@@ -93,7 +93,7 @@ def blog_post_list(request, tag=None, year=None, month=None, username=None,
     return render(request, templates, context)
 
 
-def blog_post_detail(request, slug, year=None, month=None,
+def blog_post_detail(request, slug, year=None, month=None, day=None,
                      template="blog/blog_post_detail.html"):
     """. Custom templates are checked for using the name
     ``blog/blog_post_detail_XXX.html`` where ``XXX`` is the blog
