@@ -13,8 +13,7 @@ from mezzanine.utils.urls import admin_url
 
 
 page_fieldsets = deepcopy(DisplayableAdmin.fieldsets)
-page_fieldsets[0][1]["fields"] += (("in_navigation", "in_footer"),
-                                    "login_required",)
+page_fieldsets[0][1]["fields"] += ("in_menus", "login_required",)
 
 
 class PageAdmin(DisplayableAdmin):
@@ -44,7 +43,17 @@ class PageAdmin(DisplayableAdmin):
             # fields. Do so in reverse order to retain the order of
             # the model's fields.
             for field in reversed(self.model._meta.fields):
-                if field not in Page._meta.fields and field.name != "page_ptr":
+                check_fields = [f.name for f in Page._meta.fields]
+                check_fields.append("page_ptr")
+                try:
+                    check_fields.extend(self.exclude)
+                except (AttributeError, TypeError):
+                    pass
+                try:
+                    check_fields.extend(self.form.Meta.exclude)
+                except (AttributeError, TypeError):
+                    pass
+                if field.name not in check_fields and field.editable:
                     self.fieldsets[0][1]["fields"].insert(3, field.name)
 
     def in_menu(self):
@@ -121,8 +130,6 @@ class PageAdmin(DisplayableAdmin):
         parent = request.GET.get("parent")
         if parent is not None and not change:
             obj.parent_id = parent
-            obj._order = None
-            obj.slug = None
             obj.save()
         super(PageAdmin, self).save_model(request, obj, form, change)
 
